==> gy-common-cli-1.0.3.tgz: package/lib/utils/npmInstall.js <==
const EventEmitter = require('events')
const execa = require('execa')

const taobaoDistURL = 'https://npm.taobao.org/dist'
const registries = {
  npm: 'https://registry.npmjs.org',
  taobao: 'https://registry.npm.taobao.org'
}

/**
 * 是否使用淘宝镜像
 * @param {*} command
 * @returns
 */
const shouldUseTaobao = async function (command) {
  if (command === 'cnpm') {
    return true
  }
  return false
}

const addRegistryToArgs = async function (command, args) {
  const altRegistry = shouldUseTaobao(command) ? registries.taobao : null

  if (altRegistry) {
    args.push(`--registry=${altRegistry}`)
    if (altRegistry === registries.taobao) {
      args.push(`--disturl=${taobaoDistURL}`)
    }
  }
}

class InstallProgress extends EventEmitter {
  constructor() {
    super()

    this._progress = -1
  }

  get progress() {
    return this._progress
  }

  set progress(value) {
    this._progress = value
    this.emit('progress', value)
  }

  get enabled() {
    return this._progress !== -1
  }

  set enabled(value) {
    this.progress = value ? 0 : -1
  }

  log(value) {
    this.emit('log', value)
  }
}

const progress = new InstallProgress()

function executeCommand(command, args, targetDir) {
  return new Promise((resolve, reject) => {
    progress.enabled = false

    const child = execa(command, args, {
      cwd: targetDir,
      stdio: ['inherit', 'pipe', 'inherit']
    })

    child.stdout.on('data', buffer => {
      const text = buffer.toString().trim()
      if (text) {
        console.log(`/n ${text}`)
      }
    })

    child.on('close', code => {
      if (code !== 0) {
        reject(`command failed: ${command} ${args.join(' ')}`)
        return
      }
      resolve()
    })
  })
}

const npmInstall = async function npmInstall(targetDir, command) {
  const args = ['install', '--loglevel', 'error']
  await addRegistryToArgs(command, args)
  await executeCommand(command, args, targetDir)
}

module.exports = npmInstall

==> gy-common-cli-1.3.3.tgz: package/lib/utils/npmInstall.js <==
const EventEmitter = require("events")
const execa = require("execa")

const taobaoDistURL = "https://npm.taobao.org/dist"
const registries = {
  npm: "https://registry.npmjs.org",
  taobao: "https://registry.npm.taobao.org"
}

/**
 * 是否使用淘宝镜像
 * @param {*} command
 * @returns
 */
const shouldUseTaobao = async function (command) {
  if (command === "cnpm") {
    return true
  }
  return false
}

const addRegistryToArgs = async function (command, args) {
  const altRegistry = shouldUseTaobao(command) ? registries.taobao : null

  if (altRegistry) {
    args.push(`--registry=${altRegistry}`)
    if (altRegistry === registries.taobao) {
      args.push(`--disturl=${taobaoDistURL}`)
    }
  }
}

class InstallProgress extends EventEmitter {
  constructor() {
    super()

    this._progress = -1
  }

  get progress() {
    return this._progress
  }

  set progress(value) {
    this._progress = value
    this.emit("progress", value)
  }

  get enabled() {
    return this._progress !== -1
  }

  set enabled(value) {
    this.progress = value ? 0 : -1
  }

  log(value) {
    this.emit("log", value)
  }
}

const progress = new InstallProgress()

function executeCommand(command, args, targetDir) {
  return new Promise((resolve, reject) => {
    progress.enabled = false

    const child = execa(command, args, {
      cwd: targetDir,
      stdio: ["inherit", "pipe", "inherit"]
    })

    child.stdout.on("data", buffer => {
      const text = buffer.toString().trim()
      if (text) {
        console.log(`/n ${text}`)
      }
    })

    child.on("close", code => {
      if (code !== 0) {
        reject(`command failed: ${command} ${args.join(" ")}`)
        return
      }
      resolve()
    })
  })
}

const npmInstall = async function npmInstall(targetDir, command) {
  const args = ["install", "--loglevel", "error"]
  await addRegistryToArgs(command, args)
  await executeCommand(command, args, targetDir)
}

module.exports = npmInstall
